@@ -19,7 +19,7 @@ use std::env;
 use std::iter::once;
 
 #[cfg(windows)]
-pub fn initialize() {
+pub fn initialize() -> bool {
     env::set_var("RUST_LOG", "info");
     logger::init();
     info!("OS: Windows");
@@ -27,6 +27,7 @@ pub fn initialize() {
     info!("NXUI is being initialized.");
     enable_visual_style();
     info!("Visual Style applied.");
+    true
 }
 
 #[cfg(macos)]
