@@ -1,8 +1,9 @@
+use winapi::um::commctrl::InitCommonControls;
 use crate::io::get_app_dirs;
 use crate::io::storage::Storage;
-use crate::natives_and_messaging::WT_BUTTON;
-use crate::widget::Widget;
-use crate::window::{Application, Attributes, Frame};
+use crate::messagebox::MessageBox;
+use crate::natives_and_messaging::*;
+use crate::window::{Application, Frame};
 
 #[cfg(windows)]
 /// Run nxui::window::Application
@@ -28,6 +29,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
                     PostQuitMessage(0);
                     0
                 }
+
                 _ => DefWindowProcA(window, message, wparam, lparam),
             }
         }
@@ -52,9 +54,12 @@ pub fn create_new_app(application: Box<dyn Application>) {
 
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
-
         let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("{}\0",attributes.title).as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
-        CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("{}\0",attributes.title).as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, win, 0, instance, std::ptr::null_mut());
+        if win == 0 {
+            MessageBox::new("NXUI Error", "NXUI Error - Code 0001\rWindow could not be initialized\r \rDetailed information:\rPanicked at nxui::nxui::create_new_app()\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_ERROR, BS_OK).show(Frame::default());
+            panic!("Window could not be initialized");
+        }
+
         info!("A window has been created. handle: {}",win);
 
         let frame = Frame::new(win);
@@ -65,6 +70,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
         let mut message = std::mem::zeroed();
 
         while GetMessageA(&mut message, 0, 0, 0) != 0 {
+            TranslateMessage(&message);
             DispatchMessageA(&message);
         }
         info!("Exit Phase");
